Crate rigsql_i18n
rigsql_
i18n
0.5.0
All Items
Crate Items
Functions
Crate
rigsql_
i18n
Functions

get_
locale
Get the current global locale.
rule_
description
Get a translated rule description by rule code (e.g. “LT01”). Falls back to the provided default if no translation exists.
rule_
explanation
Get a translated rule explanation by rule code (e.g. “LT01”). Falls back to the provided default if no translation exists.
rule_
message
Translate a violation message using its key and parameters. Returns the translated message with parameters substituted. Falls back to
fallback
if no translation is found or key is empty.
set_
locale
Set the global locale. Use “en”, “ja”, etc.
t
Translate a CLI message key with no parameters.